@@ -117,6 +117,9 @@ static void show_info(int what, struct xmp_module_info *mi)
 	case 'S':
 		info_samples(mi);
 		break;
+	case 'c':
+		info_comment(mi);
+		break;
 	case 'm':
 		info_mod(mi);
 		break;
@@ -384,6 +387,8 @@ int main(int argc, char **argv)
 
 			played = 1;
 
+			xmp_set_player(xc, XMP_PLAYER_AMP, opt.amplify);
+
 			if (opt.mix >= 0) {
 				xmp_set_player(xc, XMP_PLAYER_MIX, opt.mix);
 			}
@@ -424,6 +429,13 @@ int main(int argc, char **argv)
 			if (opt.verbose > 1) {
 				info_instruments(&mi);
 			}
+
+			if (opt.show_comment) {
+				if (mi.comment != NULL) {
+					report("\n");
+					info_comment(&mi);
+				}
+			}
 	
 			/* Play sequence */
 
